@@ -350,6 +350,10 @@ class Eniam():
         if valence is None:
             valence = dict()
 
+        for key in lexicon:
+            if hasattr(lexicon[key], 'rule'):
+                lexicon[key] = lexicon[key].rule()
+
         lexicon_custom = []
         for key in lexicon:
             if "__pos__" in key:
