@@ -99,13 +99,13 @@ class gram():
     def __mul__(self, other):
         return gram(f"{self.value}*{other.rule()}")
 
-    def __lt__(self, other):
-        return gram(f"({self.value})/({other.rule()})")
-
-    def __div__(self, other):
-        return gram(f"({self.value})/({other.rule()})")
-
     def __gt__(self, other):
+        return gram(f"({self.value})/({other.rule()})")
+
+    def _floordiv__(self, other):
+        return gram(f"({self.value})/({other.rule()})")
+
+    def __lt__(self, other):
         return gram(f"({self.value})\\({other.rule()})")
 
     def __or__(self, other):
@@ -135,7 +135,7 @@ def quant(gr, values):
         else:
             val_str = str(val)
         quant_conds.append(f"{key}={val_str}")
-    return "QUANT[" + ",".join(quant_conds) + "]"
+    return "QUANT[" + ",".join(quant_conds) + "] " + gr.rule()
 
 infp = gram('infp')
 np = gram('np')
@@ -301,3 +301,4 @@ inst = gram('inst')
 loc = gram('loc')
 postp = gram('postp')
 n = gram('n')
+sg = gram('sg')
